#!/usr/bin/python
# -*- coding: utf-8 -*-

from initial_load import InitialLoad
from update_from_google import UpdateFromGoogle
from update_to_google import UpdateToGoogle
from update_from_postrank import UpdateFromPostrank
from settings import Settings, NotConfigured
from mekk.feeds import GoogleReaderClient, PostRankClient
from mekk.feeds.orgfile import OrgFile
import sys,os

import logging
#logging.basicConfig(level = logging.DEBUG)
logging.basicConfig(level = logging.WARN)

COMMANDS = dict(
    init = InitialLoad,
    get = UpdateFromGoogle,
    put = UpdateToGoogle,
    postrank = UpdateFromPostrank,
)

def help():
    print """Usage:
    
%(name)s init  - create initial feeds.org

   Downloads your current Google Reader subscriptions, and saves
   them as (new) feeds.org file. Use it only once.

%(name)s get   - update feeds.org

   Checks for the feeds newly subscribed in Google Reader and 
   adds them to the (existing) feeds.org file.

%(name)s postrank - update feeds.org with postrank feed identifiers

   For any feed that is not private and is not disabled (and does not
   already have postrank_feed set) grabs the postrank feed url. Makes
   it possible to use postrank filtering.

%(name)s put   - push changes back to Google Reader

   Analyzes the feeds.org file (= your edits) and saves those changes
   back to Google Reader:
   - unsubscribes feeds marked as :disabled:
   - adds/removes Reader tags according to the file structure
   - subscribes new feeds (in particular, those no longer :disabled:)
   - replaces default feeds with PostRank feeds (for filtered feeds)

""" % dict(name = os.path.basename(sys.argv[0]))

def main():
    try:
        settings = Settings()
    except NotConfigured, e:
        print
        print e
        sys.exit(1)

    command = ""
    if len(sys.argv) == 2:
        command = sys.argv[1]
    if not command or command == "help":
        help()
        sys.exit(1)

    try:
        reader = GoogleReaderClient(** settings.google_auth())
        postrank = PostRankClient("mekk.waw.pl")
        org_file = OrgFile(settings.org_file(), True)
    
        cmdobj = COMMANDS[sys.argv[1]](reader, org_file, postrank)
        cmdobj.execute()
    except Exception, e:
        print 
        print e, type(e)
        #sys.exit(1)
        raise


